
(IN-PACKAGE "COMPILER") 

(PROCLAIM '(FTYPE (FUNCTION (T FIXNUM FIXNUM) T) DASH-TO-UNDERSCORE-INT))
(PROCLAIM '(FTYPE (FUNCTION (T FIXNUM T) T) C-FUNCTION-NAME))
(PROCLAIM '(FTYPE (FUNCTION (FIXNUM FIXNUM) T) MLIN)) 
(PROCLAIM '(FTYPE (FUNCTION (T) T)  COPY-ARRAY COPY-INFO DASH-TO-UNDERSCORE)) 
(PROCLAIM '(FTYPE (FUNCTION (T T FIXNUM T) FIXNUM)  PUSH-ARRAY)) 
(PROCLAIM '(FTYPE (FUNCTION (T T FIXNUM FIXNUM T) FIXNUM) BSEARCHLEQ)) 
(PROCLAIM '(FTYPE (FUNCTION (T) FIXNUM) F-TYPE)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T T) FIXNUM) PROCLAIMED-ARGD ANALYZE-REGS
            ANALYZE-REGS1)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T T T) *) WT-INLINE C2COMPILER-LET C2FLET
            C2LABELS C2IF)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T T T T) *) C1DM-VL C1DM-V C2RETURN-FROM
            C2APPLY-OPTIMIZE C2DM)) 
(PROCLAIM '(FTYPE (FUNCTION (T T *) *) T3DEFUN-AUX)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T T T) T) CJT BOOLE3 WT-INLINE-COND
            WT-INLINE-FIXNUM WT-INLINE-INTEGER WT-INLINE-CHARACTER
            WT-INLINE-LONG-FLOAT WT-INLINE-SHORT-FLOAT C1MAP-FUNCTIONS
            C2MAPCAR C2MAPC C2MAPCAN FIX-DOWN-ARGS C2PROGV
            WT-IF-PROCLAIMED C1STRUCTURE-REF1 SET-VAR ASSIGN-DOWN-VARS
            C2MULTIPLE-VALUE-BIND C2PRINC C1DM TOO-MANY-ARGS
            TOO-FEW-ARGS T3DEFCFUN CMP-EXPAND-MACRO
            ADD-FUNCTION-PROCLAMATION ADD-FUNCTION-DECLARATION
            CAN-BE-REPLACED* GET-INLINE-INFO C2LET* SUBLIS1-INLINE
            CHECK-VDECL C2TAGBODY C2GO C2CASE AND-FORM-TYPE
            CHECK-FORM-TYPE C2FUNCALL-SFUN ADD-FAST-LINK WT-MAKE-CCLOSURE
            INLINE-TYPE-MATCHES CJF C2LET MAKE-INLINE-STRING)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T T *) T) INLINE-ARGS C2FUNCALL C2LAMBDA-EXPR)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T T T T) T) C2CALL-UNKNOWN-GLOBAL T3DEFUN-VARARG
            T3DEFUN-NORMAL MY-CALL WT-GLOBAL-ENTRY C1MAKE-VAR
            C2STRUCTURE-REF C2SWITCH C2CALL-GLOBAL)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T T T T T) T) T3DEFUN-LOCAL-ENTRY T3DEFUN
            C1APPLY-OPTIMIZE C2STRUCTURE-SET
            T2DEFUN T2DEFENTRY T3DEFENTRY)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T T T T T *) T) T3LOCAL-DCFUN T3LOCAL-FUN)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T T T T T T) T) DEFSYSFUN T2DEFMACRO T3DEFMACRO)) 
(PROCLAIM '(FTYPE (FUNCTION (T T T *) T) WT-SIMPLE-CALL)) 
(PROCLAIM '(FTYPE (FUNCTION NIL *) WT-FASD-DATA-FILE WT-DATA-FILE)) 
(PROCLAIM
    '(FTYPE (FUNCTION NIL T) CCB-VS-PUSH WFS-ERROR WT-NEXT-VAR-ARG
            CLOSE-INLINE-BLOCKS WT-FIRST-VAR-ARG WT-DATA-BEGIN
            WT-DATA-END C1T ADD-LOAD-TIME-SHARP-COMMA RESET-TOP
            CVS-PUSH WT-CVARS PRINT-CURRENT-FORM INIT-ENV
            INC-INLINE-BLOCKS WT-C-PUSH VS-PUSH C1NIL BABOON
            TAIL-RECURSION-POSSIBLE)) 
(PROCLAIM '(FTYPE (FUNCTION (*) *) INLINE-BOOLE3)) 
(PROCLAIM
    '(FTYPE (FUNCTION (*) T) MAKE-INFO FCALLN-INLINE MAKE-BLK
            LIST-INLINE LIST*-INLINE MAKE-FUN MAKE-TAG CS-PUSH MAKE-VAR
            WT-CLINK)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T) *) SET-LOC T1EXPR C2EXPR C2PROGN T1EVAL-WHEN
            CMP-TOPLEVEL-EVAL CMP-EVAL WT-TO-STRING C2AND C2OR WT-LOC
            WT-FIXNUM-LOC WT-CHARACTER-LOC WT-LONG-FLOAT-LOC
            WT-SHORT-FLOAT-LOC)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T) T) VAR-REP-LOC WT-VV WT-CAR WT-CDR DECLARATION-TYPE
            WT-CADR ADD-OBJECT VOLATILE C2BIND WT-VS-BASE C2FUNCALL-AUX
            INFO-P C1FUNOB VAR-NAME VAR-REF WT-FUNCTION-LINK
            VAR-REF-CCB WT-FUNCALL-C VAR-LOC VAR-TYPE SAVE-FUNOB
            VAR-REGISTER FIXNUM-LOC-P CHARACTER-LOC-P LONG-FLOAT-LOC-P
            SHORT-FLOAT-LOC-P VERIFY-DATA-VECTOR C1PROGV
            ARGS-CAUSE-SIDE-EFFECT WT-DATA-PACKAGE-OPERATION C1MAPCAR
            C1MAPLIST NAME-TO-SD PROCLAIM T1ORDINARY C1PROGN
            PROCLAMATION C1MAPC C1MAPL WT-H1 C1VAR T1PROGN
            CHECK-DOWNWARD C1MAPCAN C1FMLA-CONSTANT CHECK-VREF C1MAPCON
            ADD-SYMBOL WT-VS* FLAGS-POS C1VREF C1CATCH VARARG-P MAXARGS
            INFO-CHANGED-VARS C1EXPR C1UNWIND-PROTECT ADD-ADDRESS
            C1MULTIPLE-VALUE-CALL INFO-REFERRED-VARS
            INLINE-BOOLE3-STRING INFO-TYPE AET-C-TYPE RESULT-TYPE
            C1THROW C1MULTIPLE-VALUE-PROG1 C2DM-RESERVE-VL
            INFO-SP-CHANGE WT-CCB-VS C2DM-RESERVE-V INFO-VOLATILE
            GET-INCLUDED C1STRUCTURE-REF SET-PUSH-CATCH-FRAME C1VALUES
            CONS-TO-LISTA C1BLOCK C2VALUES C2VAR-KIND
            C1MULTIPLE-VALUE-SETQ C1STRUCTURE-SET WT-VAR-DECL
            CONSTANT-FOLD-P C1RETURN-FROM SET-UP-VAR-CVS
            C1MULTIPLE-VALUE-BIND C1PRINC C1SHARP-COMMA
            C1DEFINE-STRUCTURE C1DOWNWARD-FUNCTION C1TERPRI
            PARSE-CVSPECS C2DOWNWARD-FUNCTION C1APPLY REPLACE-CONSTANT
            T1DEFUN WT-DOWNWARD-CLOSURE-MACRO FASD-EVALD_FORMS
            T1DEFMACRO THE-PARAMETER C1FUNCALL FASD-TABLE_LENGTH
            T1CLINES C1RPLACA FASD-FILEPOS C1PSETQ T1DEFCFUN
            C1DM-BAD-KEY C2RPLACA FASD-INDEX T1DEFENTRY C1RPLACD BLK-P
            FASD-PACKAGE T1DEFLA C2RPLACD FASD-DIRECTION C1MEMQ
            FASD-EOF C1MEMBER FASD-TABLE T2ORDINARY FASD-STREAM
            T2DECLARE C1QUOTE C1ASSOC BLK-NAME C1FUNCTION BLK-REF
            C2FUNCTION C1GET BLK-REF-CLB C1THE C2GET BLK-REF-CCB
            C1EVAL-WHEN C1NTH-CONDITION BLK-EXIT T3CLINES C1DECLARE
            C1NTH BLK-VALUE-TO-GO UNDEFINED-VARIABLE C1COMPILER-LET
            C1NTHCDR-CONDITION BLK-VAR C1NTHCDR NAME-SD1 CTOP-WRITE
            REGISTER WT-SYMBOL-FUNCTION C1RPLACA-NTHCDR C1LIST-NTH
            PUSH-DATA-INCF T1DEFINE-STRUCTURE WT-DATA1
            C1BOOLE-CONDITION CMP-MACROEXPAND C1BOOLE3
            CMP-MACROEXPAND-1 C1IF FUNCTION-ARG-TYPES C1ASH-CONDITION
            SCH-LOCAL-FUN C1ASH SCH-GLOBAL C1LENGTH ADD-CONSTANT VAR-P
            WT1 VAR-KIND REP-TYPE ADD-REG1 GET-ARG-TYPES C1ADD-GLOBALS
            GET-RETURN-TYPE ADD-LOOP-REGISTERS C1FLET
            GET-LOCAL-ARG-TYPES C2TAGBODY-CCB C1OR
            GET-LOCAL-RETURN-TYPE C2TAGBODY-CLB WRITE-BLOCK-OPEN
            C1LABELS C2TAGBODY-LOCAL C2TAGBODY-BODY C1LET C1MACROLET
            INLINE-POSSIBLE WT-SWITCH-CASE C1LET* C2GO-CCB SAVE-AVMA
            C2GO-CLB C1STACK-LET C2GO-LOCAL FUN-P C1TAGBODY
            C1LOCAL-CLOSURE C1GO WT-LIST C1LOCAL-FUN CMP-MACRO-FUNCTION
            TAG-P C1ECASE OBJECT-TYPE C1SWITCH C2EXPR* RESET-INFO-TYPE
            DEFAULT-INIT TAG-NAME INLINE-TYPE C1AND PUSH-ARGS TAG-REF
            PUSH-ARGS-LISPCALL TAG-REF-CLB SET-RETURN
            NEED-TO-SET-VS-POINTERS WT-DOWN TAG-REF-CCB SET-TOP
            TAG-LABEL FUN-NAME FIX-OPT C2LOCATION TAG-UNWIND-EXIT
            FUN-REF SYSTEM:UNDEF-COMPILER-MACRO WT-VS C2VAR TAG-VAR
            FUN-REF-CCB C1SETQ TYPE-FILTER TAG-SWITCH UNWIND-NO-EXIT
            FUN-CFUN CLINK FUN-LEVEL FUNCTION-RETURN-TYPE)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T *) T) UNWIND-EXIT WT-COMMENT CMPERR ADD-INIT
            CMPWARN CMPNOTE C1CASE WT-INTEGER-LOC C1LAMBDA-EXPR
            FAST-LINK-PROCLAIMED-TYPE-P WT-CVAR)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T T) *) C2BLOCK-LOCAL C1SYMBOL-FUN
            C2RETURN-LOCAL C2BLOCK C1BODY C2DECL-BODY WT-INLINE-LOC)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T T) T) VAR-REP-EQ INLINE-PROC SET-BDS-BIND UNWIND-BDS
            RESULT-TYPE-FROM-ARGS C2BIND-LOC WT-FIXNUM-VALUE
            C2BIND-INIT WT-CHARACTER-VALUE WT-LONG-FLOAT-VALUE
            WT-SHORT-FLOAT-VALUE ADD-INFO ARGS-INFO-REFERRED-VARS
            SHIFT>> SHIFT<< COMPILER-CLEAR-COMPILER-PROPERTIES
            MAYBE-EVAL PUSH-CHANGED-VARS SET-JUMP-TRUE C2BLOCK-CCB
            C2DM-BIND-VL C1CONSTANT-VALUE C2BLOCK-CLB CMPFIX-ARGS
            C1LAMBDA-FUN CO1CONSTANT-FOLD
            C2LAMBDA-EXPR-WITH-KEY C1ARGS MULTIPLE-VALUE-CHECK
            C2LAMBDA-EXPR-WITHOUT-KEY C2CATCH C2EXPR-TOP C1EXPR*
            C2UNWIND-PROTECT C2RETURN-CCB ADD-DEBUG-INFO
            C2MULTIPLE-VALUE-CALL C2RETURN-CLB STRUCT-TYPE-OPT C2THROW
            C2MULTIPLE-VALUE-PROG1 WT-REQUIREDS C2DM-BIND-LOC C1FMLA
            C2DM-BIND-INIT FAST-READ WT-V*-MACROS CFAST-WRITE
            C2MULTIPLE-VALUE-SETQ WT-MAKE-DCLOSURE C2APPLY C2EXPR-TOP*
            C1PROGN* COMPILER-DEF-HOOK C2MEMBER!2
            T2SHARP-COMMA C2ASSOC!2 SYSTEM::ADD-DEBUG
            C2LIST-NTH-IMMEDIATE SET-DBIND CONVERT-CASE-TO-SWITCH
            PROCLAIM-VAR CO1LDB CO1EQL COERCE-LOC
            ARGS-INFO-CHANGED-VARS CO1TYPEP JUMPS-TO-P CO1SCHAR CO1CONS
            CO1READ-BYTE CO1READ-CHAR WT-VAR CAN-BE-REPLACED
            CO1WRITE-BYTE CO1WRITE-CHAR CO1VECTOR-PUSH
            CO1STRUCTURE-PREDICATE CO1SPECIAL-FIX-DECL C1DECL-BODY
            CO1SUBLIS GET-INLINE-LOC C2STACK-LET NEED-TO-PROTECT SET-VS
            TYPE-AND SET-JUMP-FALSE C2CALL-LOCAL
            COERCE-LOC-STRUCTURE-REF C2CALL-LAMBDA C1SETQ1 TYPE>=
            C2PSETQ C2SETQ CHECK-FNAME-ARGS)) 